import { select, rollup, mean } from 'd3';
import { viz } from './viz';
import { data } from '@RenoBlitz/054442a0baff480c9e1054cb77f51ecd';
import { observeResize } from '@drbagwell/responsive-viz-axes';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const dataByYear = rollup(
    data,
    (v) => mean(v, (d) => d.price),
    (d) => d.year_sale,
  );

  const processedData = Array.from(
    dataByYear,
    ([year, averagePrice]) => ({ year, averagePrice }),
  );

  viz(svg, {
    data: processedData,
    xValue: (d) => d.year,
    xAxisLabelText: 'Year',
    xAxisLabelOffset: 35,
    yValue: (d) => d.averagePrice,
    yAxisLabelText: 'Average Pirce',
    yAxisLabelOffset: 20,
    circleRadius: 500 / 100,
    circleOpacity: 569 / 1000,
    marginTop: 90,
    marginRight: 50,
    marginBottom: 50,
    marginLeft: 90,
    width,
    height,
    innerRectFill: '#FFFFFF',
  });
};
